import { HttpClient, HttpErrorResponse } from "@angular/common/http";
import { Observable } from 'rxjs';
import { InjectionToken } from "@angular/core";
import { MasterService } from '../service/yaya-master-service';
/**
 * 错误处理
 */
export declare type HandleError = <T>(operation?: string, result?: T) => (error: HttpErrorResponse) => Observable<T>;
/**
 * 环境变量设置
 */
export declare const YAYA_API_ENV: InjectionToken<string>;
/**
 * http请求封装
 */
export declare class YHttp {
    private http;
    private env;
    private master;
    private createHandleError;
    constructor(http: HttpClient, env: any, master: MasterService);
    get<T>(apiCode: string, params?: any, headers?: any, result?: T): Observable<T>;
    post<T>(apiCode: string, body: any, headers?: any, result?: T): Observable<T>;
    private handleError<T>(api?, result?);
    /**
     * 通过api编码获取接口路径
     * 如果未找到则抛出异常
     * @param code api编码
     */
    private getPathByCode(code);
    /**
     * 配置文件预处理
     * 1. 创建env的观察者对象方便后续操作
     * 2. 创建api的观察者对象方便后续操作
     * 3. 设置默认环境信息
     * 4. 对不规范路径信息进行处理
     */
    private configPreHandle();
    private responseHandle(api, res);
    private buildFaultResult<T>(message);
    private buildResult<T>(result);
}
